@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: SOAP.pm,v 1.3 2007/10/03 18:31:49 kutterma Exp $
+# $Id: SOAP.pm,v 1.4 2008/01/03 15:20:05 kutterma Exp $
 #
 # ======================================================================
 
@@ -19,6 +19,10 @@ $VERSION = '0.69_01';
 
 my $server = __PACKAGE__->new;
 
+sub server {
+    return $server;
+}
+
 sub handler {
   $server->configure(@_);
   $server->SUPER::handler(@_);
@@ -106,6 +110,20 @@ SOAP::Transport::HTTP documentation for other options.
 
 =back
 
+=head1 METHODS/SUBROUTINES
+
+=head2 server
+
+ my $server = Apache::XMLRPC::Lite->server();
+
+Returns the server object.
+
+Useful if you need to manipulate the server object from your code.
+
+=head2 handle
+
+Request handler. Called by apache.
+
 =head1 DEPENDENCIES
 
  SOAP::Lite
